<?php

// recursive function
function nc_rec_menu_list_pages( $pages, $childof=0 )
{
    if ( !is_array($pages[$childof]['children']) ) return;
    foreach( $pages[$childof]['children'] as $id )
    {
        $title = $pages[$id]['title'];
        echo "<li><h2><a href=\"".get_page_link($id)."\">$title</a></h2>".
                (($meta = get_post_meta($id,"description",true)) ? "<p>$meta</p>" : "");
        if ( is_array($pages[$id]['children']) )
        {
            echo "<ul>";
            nc_rec_menu_list_pages( $pages, $id );
            echo "</ul>";
        }
        echo "</li>";
    }
}

// list pages for the menu
// based off of the default wp_list_pages
function nc_menu_list_pages( $args )
{
    $pages = & get_pages( $args );
    if ( $pages )
    {
        $pagetree = array();
        foreach ( $pages as $page )
        {
            $pagetree[$page->ID]['title'] = $page->post_title;
            $pagetree[$page->ID]['name'] = $page->post_name;
            if ( $page->post_parent != $page->ID )
            {
                $pagetree[$page->post_parent]['children'][] = $page->ID;
            }
        }
        nc_rec_menu_list_pages( $pagetree, 0 );
    }
}

// used to render categories in a friendlier manner
// formatted like Cat1, Cat2, and Cat3 instead of
// the more 'robotic' Cat1, Cat2, Cat3
function nc_category_friendly( )
{
    $cats = get_the_category( );
    $c = count($cats);
    $l = '';
    if ( $c == 0 )
    {
        $l = 'no category';
    }
    else
    {
        $p = 0;
        foreach( $cats as $cat )
        {
            $l .= '<a href="'.get_category_link($cat->cat_ID).'">'.$cat->cat_name.'</a>, ';
        }
        $l = substr( $l, 0, strlen($l)-2 );
        if ($c > 1)
            $l = substr_replace( $l, " and ", strrpos( $l, ', ' ), 2 );
    }
    echo apply_filters('the_category', $l, ', ', 'single');
}

if ( function_exists('UTW_ShowCurrentTagSet') )
{
    function nc_get_tags( )
    {
        global $utw,$post;
        $format = array(
        'pre'=>'',
        'post'=>'',
        'single'=>'Tagged as %taglink%.',
        'none'=>'',
        'defaut'=>', %taglink%',
        'first'=>'Tagged as %taglink%',
        'last'=>' and %taglink%.'
        );
        $tags = $utw->GetTagsForPost($post, 0);
        $c = count($tags);
        if ( $c == 0 )
        {
            $l = "Post is not tagged.";
        }
        else
        {
            $l = $utw->FormatTags($tags, $utw->GetFormat('commalistwithtaglabel', $format));
        }
        echo $l;
    }
}
else
{
    function nc_get_tags( )
    {
        // do nothing like a man!
    }
}

function nc_nav_links( )
{
    if ( !have_posts() )
    {
        return;
    }
    $t = '<div class="navbar">';
    if ( is_single( ) )
    {
        $next = get_next_post( );
        $prev = get_previous_post( );

        if( $prev )
        {
            $t .= '<h2 class="left"><a href="'.get_permalink($prev->ID).'">Older</a></h2>';
        }
        if( $next )
        {
            $t .= '<h2 class="right"><a href="'.get_permalink($next->ID).'">Newer</a></h2>';
        }
        if ( !$next && !$prev )
        {
            return;
        }
    }
    else
    {
        $ver = intval(str_replace(substr(get_bloginfo('version'), 0, 3),'.',''));
        if ( $ver == 0 || $ver >= 21 )
        {
            // mostly ripped from WP source, pretty much
            global $wp_query;
    
            $max_num_pages = $wp_query->max_num_pages;
            $paged = get_query_var('paged');
            if ($max_num_pages < 2)
                return;
        }
        else
        {
            global $paged, $result, $request, $posts_per_page, $wpdb, $max_num_pages;

            // ripped from the Wordpress source, makes formatting easier
            if ( isset($max_num_pages) ) {
                $max_page = $max_num_pages;
            } else {
                preg_match('#FROM\s(.*)\sGROUP BY#siU', $request, $matches);
                $fromwhere = $matches[1];
                $numposts = $wpdb->get_var("SELECT COUNT(DISTINCT ID) FROM $fromwhere");
                $max_page = $max_num_pages = ceil($numposts / $posts_per_page);
            }
            // end rip
        }

        $next = nc_next_posts( $max_page );
        $prev = nc_previous_posts( );
        if( $next )
        {
            $t .= "<h2 class=\"left\"><a href=\"$next\">Older</a></h2>";
        }
        if( $prev )
        {
            $t .= "<h2 class=\"right\"><a href=\"$prev\">Newer</a></h2>";
        }
        if ( !$next && !$prev )
        {
            return;
        }
    }
    $t .= '</div>';
    echo $t;
}

// function from WordPress, modified to return info instead of echoing it
function nc_next_posts($max_page = 0) { // original by cfactor at cooltux.org
    global $paged, $pagenow;

    if ( !is_single() ) {
        if ( !$paged )
            $paged = 1;
        $nextpage = intval($paged) + 1;
        if ( !$max_page || $max_page >= $nextpage )
            return get_pagenum_link($nextpage);
    }
    return 0;
}

// function from WordPress, modified to return info instead of echoing it
function nc_previous_posts() { // original by cfactor at cooltux.org
    global $paged, $pagenow;

    if ( !is_single() ) {
        $nextpage = intval($paged) - 1;
        if ( $nextpage < 1 )
            return '';
        return get_pagenum_link($nextpage);
    }
    return 0;
}

?>
